local StoneGate = ...

-- Apply building asset processor
StoneGate:registerAssetProcessor("models/core.fbx", {
    DataType = "BUILDING_ASSET_PROCESSOR"
})

StoneGate:registerAssetId("models/core.fbx/Prefab/CoreBuildingPart", StoneGateSetPrefix .. "_CORE_BUILDING_PREFAB")

-- Register the Core part
StoneGate:registerAsset({
	DataType = "BUILDING_PART",
	Id = StoneGateSetPrefix .. "_CORE_BUILDING_PART",
	Name = StoneGateSetPrefix .. "_CORE_BUILDING_NAME",
	Description = StoneGateSetPrefix .. "_CORE_BUILDING_DESC",
	Category = "CORE",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = StoneGateSetPrefix .. "_CORE_BUILDING_PREFAB"
	},
        IsVisibleWhenBuilt = false
})


    _MainBuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( {8, 12} ),
              Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } }
    }}
    _KeepBuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( {8, 8} ),
              Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } }
    }}
    _SstBuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( {4, 4} ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } },
            { Polygon = polygon.createRectangle( {4, 2} ),
              Type = { DEFAULT = false, NAVIGABLE = true, GRASS_CLEAR = false } },
            { Polygon = polygon.createRectangle( {2, 4} ),
              Type = { DEFAULT = false, NAVIGABLE = true, GRASS_CLEAR = false } }
    }}
    _SstStairBuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( {4, 4} ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } },
            { Polygon = polygon.createRectangle( {2, 4} ),
              Type = { DEFAULT = false, NAVIGABLE = true, GRASS_CLEAR = false } }
    }}
    _SstGateBuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( { 4, 4}, { 0, 0 } ),
              Type = { DEFAULT = false, NAVIGABLE = false, GRASS_CLEAR = true } },
            { Polygon = polygon.createRectangle( { 4, 1 }, { 0, 1.5 } ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = false } },
            { Polygon = polygon.createRectangle( { 4, 1 }, { 0, -1.5 } ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = false } },
            { Polygon = polygon.createRectangle( { 2, 4 }, { 0, 0 } ),
              Type = { DEFAULT = false, NAVIGABLE = true, GRASS_CLEAR = false } }
    }}
    local OtowerVarTemp = 2/math.tan(math.pi/8)
    _OTowerBuildingZone = { ZoneEntryList = {
            { Polygon = {
                  {-2, OtowerVarTemp},
                  {2, OtowerVarTemp},
                  {OtowerVarTemp, 2},
                  {OtowerVarTemp, -2},
                  {2, -OtowerVarTemp},
                  {-2, -OtowerVarTemp},
                  {-OtowerVarTemp, -2},
                  {-OtowerVarTemp, 2} },
              Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } }
    }}
    _LGate2BuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( { 8, 2 }, { 0, -3 } ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = false } },
            { Polygon = polygon.createRectangle( { 8, 2 }, { 0, 3 } ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = false } },
            { Polygon = polygon.createRectangle( { 8, 8 }, { 0, 0 } ),
              Type = { DEFAULT = false, NAVIGABLE = true, GRASS_CLEAR = true } }
    }}
    _LGate2_2BuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( { 8, 2 }, { 0, -3 } ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = false } },
            { Polygon = polygon.createRectangle( { 2, 8 }, { -3, 0 } ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = false } },
            { Polygon = polygon.createRectangle( { 2, 2 }, { 3, 3 } ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = false } },
            { Polygon = polygon.createRectangle( { 8, 8 }, { 0, 0 } ),
              Type = { DEFAULT = false, NAVIGABLE = true, GRASS_CLEAR = true } }
    }}
    _LGate3BuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( { 8, 2 }, { 0, 3 } ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = false } },
            { Polygon = polygon.createRectangle( { 2, 2 }, { -3, -3 } ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = false } },
            { Polygon = polygon.createRectangle( { 2, 2 }, { 3, -3 } ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = false } },
            { Polygon = polygon.createRectangle( { 8, 8 }, { 0, 0 } ),
              Type = { DEFAULT = false, NAVIGABLE = true, GRASS_CLEAR = true } }
    }}
    _LGate4BuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( { 2, 2 }, { -3, -3 } ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = false } },
            { Polygon = polygon.createRectangle( { 2, 2 }, { 3, -3 } ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = false } },
            { Polygon = polygon.createRectangle( { 2, 2 }, { -3, 3 } ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = false } },
            { Polygon = polygon.createRectangle( { 2, 2 }, { 3, 3 } ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = false } },
            { Polygon = polygon.createRectangle( { 8, 8 }, { 0, 0 } ),
              Type = { DEFAULT = false, NAVIGABLE = true, GRASS_CLEAR = true } }
    }}
    _SmallGateBuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( { 4, 8}, { 0, 0 } ),
              Type = { DEFAULT = false, NAVIGABLE = false, GRASS_CLEAR = true } },
            { Polygon = polygon.createRectangle( { 4, 2 }, { 0, 3 } ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = false } },
            { Polygon = polygon.createRectangle( { 4, 2 }, { 0, -3 } ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = false } },
            { Polygon = polygon.createRectangle( { 2, 8 }, { 0, 0 } ),
              Type = { DEFAULT = false, NAVIGABLE = true, GRASS_CLEAR = false } }
    }}
    _SmallGateExtensionBuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( { 4, 8 }, { 0, 0 } ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } },
            { Polygon = polygon.createRectangle( { 2, 8 }, { 0, 0 } ),
              Type = { DEFAULT = false, NAVIGABLE = true, GRASS_CLEAR = false } }
    }}
    _SmallGateHalfRoofBuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( { 4, 8}, { 0, 0 } ),
              Type = { DEFAULT = false, NAVIGABLE = false, GRASS_CLEAR = true } },
            { Polygon = polygon.createRectangle( { 4, 2 }, { 0, 3 } ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = false } },
            { Polygon = polygon.createRectangle( { 4, 2 }, { 0, -3 } ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = false } },
            { Polygon = polygon.createRectangle( { 2, 8 }, { -1, 0 } ),
              Type = { DEFAULT = false, NAVIGABLE = true, GRASS_CLEAR = false } }
    }}
    _SmallGateExtensionHalfRoofBuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( { 4, 8 }, { 0, 0 } ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } },
            { Polygon = polygon.createRectangle( { 2, 8 }, { -1, 0 } ),
              Type = { DEFAULT = false, NAVIGABLE = true, GRASS_CLEAR = false } }
    }}
    _DrawBridgeBuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( { 2, 2 }, { 0, 0 } ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } }
    }}
    local Angle45VarTemp = 2*math.tan(math.pi/8)
    _Angle45BuildingZone = { ZoneEntryList = {
            { Polygon = {
                  {Angle45VarTemp+1, 2},
                  {Angle45VarTemp+1, -2},
                  {-Angle45VarTemp+1, -2},
                  {-4*math.cos(math.pi/4)+Angle45VarTemp+1, -4*math.sin(math.pi/4)+2} },    
              Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } }
    }}
    _Angle45KeepBuildingZone = { ZoneEntryList = {
            { Polygon = {
                  {2*(Angle45VarTemp+1), 2*2},
                  {2*(Angle45VarTemp+1), -2*2},
                  {-2*Angle45VarTemp+2, -2*2},
                  {-2*4*math.cos(math.pi/4)+2*(Angle45VarTemp+1), -2*4*math.sin(math.pi/4)+2*2} },    
              Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } }
    }}
    _CircularBuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createCircle( 3.3, { 0, 0 }, 16 ),
              Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } }
    }}
    _SmallCircularBuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createCircle( 1.5, { 0, 0 }, 24 ),
              Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } }
    }}
    _OverHangingBuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( {8, 8} ),
              Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } }
    }}
    _buildingZonePillings = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( {0.5, 0.5}, {1.75, 1.75} ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true }},
            { Polygon = polygon.createRectangle( {0.5, 0.5}, {-1.75, 1.75} ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true }},
            { Polygon = polygon.createRectangle( {0.5, 0.5}, {-1.75, -1.75} ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true }},
            { Polygon = polygon.createRectangle( {0.5, 0.5}, {1.75, -1.75} ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true }},
            { Polygon = polygon.createRectangle( {4, 2} ),
              Type = { DEFAULT = false, NAVIGABLE = true, GRASS_CLEAR = false }},
            { Polygon = polygon.createRectangle( {2, 4}),
              Type = { DEFAULT = false, NAVIGABLE = true, GRASS_CLEAR = false }} -- TBC: move to the wodenFloor Decoration D (in case of wooden bridge only)
        }
    }
    _buildingZoneWoodenStair = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( {0.5, 0.5}, {1.75, 1.75} ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true }},
            { Polygon = polygon.createRectangle( {0.5, 0.5}, {-1.75, 1.75} ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true }},
            { Polygon = polygon.createRectangle( {0.5, 0.5}, {-1.75, -1.75} ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true }},
            { Polygon = polygon.createRectangle( {0.5, 0.5}, {1.75, -1.75} ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true }},
            { Polygon = polygon.createRectangle( {2, 4} ),
              Type = { DEFAULT = false, NAVIGABLE = true, GRASS_CLEAR = false }}
        }
    }

-- Function list
    function overrideWorkplaceName(_name)
        StoneGate:overrideAsset({
                Id = "BUILDING_FUNCTION_" .. _name,
                Name = StoneGateSetPrefix .. "_BUILDING_FUNCTION_" .. _name .. "_NAME"
        })
    end
-- Waiting for dummy exposed   overrideWorkplaceName("WOODEN_KEEP")
    overrideWorkplaceName("BAKERY")
    overrideWorkplaceName("BLACKSMITH")
    overrideWorkplaceName("BUILDER_WORKSHOP")
    overrideWorkplaceName("CHEESE_MAKER")
    overrideWorkplaceName("COOPERAGE")
    overrideWorkplaceName("JEWELER_WORKSHOP")
    overrideWorkplaceName("SAWMILL")
    overrideWorkplaceName("STONEMASON_HUT")
    overrideWorkplaceName("TAILOR_WORKSHOP")
    overrideWorkplaceName("WEAPONSMITH")
    overrideWorkplaceName("WEAVER_HUT")
    overrideWorkplaceName("BREWERY")
    overrideWorkplaceName("IRON_SMELTER")
    overrideWorkplaceName("GOLD_SMELTER")
    overrideWorkplaceName("GLASS_SMELTER")
    overrideWorkplaceName("HOP_FARM")
--    overrideWorkplaceName("VINEYARD")
    overrideWorkplaceName("WHEAT_FARM")
    overrideWorkplaceName("WINDMILL")
    overrideWorkplaceName("CANDLE_WORKSHOP")
    overrideWorkplaceName("CANDLE_WORKSHOP_EXTENSION")
--    overrideWorkplaceName("COMMON_WARES_WORKSHOP") -- already defined by the game
    overrideWorkplaceName("COMMON_WARES_TOWER")

function registerAssignableFunction(_assetPrefix, _assetId)
    StoneGate:registerAsset({
		DataType = "BUILDING_FUNCTION_LIST",
                Id = _assetPrefix .. "_" .. _assetId .. "_FUNCTION_LIST",
                AssetFunctionList = {
                        "BUILDING_FUNCTION_GREAT_HALL",
                        "BUILDING_FUNCTION_BAILIFF_OFFICE",
                        "BUILDING_FUNCTION_TREASURY",
                        "BUILDING_FUNCTION_TAX_OFFICE",
--                        "BUILDING_FUNCTION_CHURCH",
--                        "BUILDING_FUNCTION_WOODEN_KEEP",
                        "BUILDING_FUNCTION_BAKERY",
                        "BUILDING_FUNCTION_BLACKSMITH",
                        "BUILDING_FUNCTION_BUILDER_WORKSHOP",
                        "BUILDING_FUNCTION_CHEESE_MAKER",
                        "BUILDING_FUNCTION_COOPERAGE",
                        "BUILDING_FUNCTION_JEWELER_WORKSHOP",
                        "BUILDING_FUNCTION_SAWMILL",
                        "BUILDING_FUNCTION_STONEMASON_HUT",
                        "BUILDING_FUNCTION_TAILOR_WORKSHOP",
                        "BUILDING_FUNCTION_WEAPONSMITH",
                        "BUILDING_FUNCTION_WEAVER_HUT",
                        "BUILDING_FUNCTION_FOOD_MARKET",
                        "BUILDING_FUNCTION_GOODS_MARKET",
                        "BUILDING_FUNCTION_LUXURY_MARKET",
                        "BUILDING_FUNCTION_SERVICE_COUNTER",
                        "BUILDING_FUNCTION_BREWERY",
                        "BUILDING_FUNCTION_IRON_SMELTER",
                        "BUILDING_FUNCTION_GOLD_SMELTER",
                        "BUILDING_FUNCTION_GLASS_SMELTER",
                        registerFunctionHouse(_assetPrefix, _assetId, "1"),
                        registerFunctionHouse(_assetPrefix, _assetId, "2"),
                        "BUILDING_FUNCTION_HOP_FARM",
--                        "BUILDING_FUNCTION_VINEYARD",
                        "BUILDING_FUNCTION_WHEAT_FARM",
                        "BUILDING_FUNCTION_WINDMILL",
                        "BUILDING_FUNCTION_CANDLE_WORKSHOP",
                        "BUILDING_FUNCTION_CANDLE_WORKSHOP_EXTENSION",
                        "BUILDING_FUNCTION_COMMON_WARES_WORKSHOP",
                        "BUILDING_FUNCTION_COMMON_WARES_TOWER",
                }
    })
    if _flagEntertainment then
        StoneGate:overrideAsset({
            Id = _assetPrefix .. "_" .. _assetId .. "_FUNCTION_LIST",
            AssetFunctionList = {
                Action = "APPEND",
                EntertainmentPrefix.."_BROTHEL_FUNCTION",
                EntertainmentPrefix.."_BARBERSHOP_FUNCTION",
                EntertainmentPrefix.."_BATHHOUSE_FUNCTION",
            }
        })
    end
    if _flagAuthority then
        StoneGate:overrideAsset({
            Id = _assetPrefix .. "_" .. _assetId .. "_FUNCTION_LIST",
            AssetFunctionList = {
                Action = "APPEND",
			"BUILDING_FUNCTION_AUTHORITY_EXCHEQUER",
			"BUILDING_FUNCTION_AUTHORITY_LORD",
			"BUILDING_FUNCTION_AUTHORITY_LADY",
			"BUILDING_FUNCTION_AUTHORITY_CHAMBERLAIN",
			"BUILDING_FUNCTION_AUTHORITY_COUNCIL",
			"BUILDING_FUNCTION_AUTHORITY_CHANCERY",
            }
        })
    end

    StoneGate:registerAsset({
		DataType = "BUILDING_FUNCTION_ASSIGNABLE",
                Id = _assetPrefix .. "_" .. _assetId .. "_ASSIGNABLE_FUNCTION",
                AuthorizedFunctionList = _assetPrefix .. "_" .. _assetId .. "_FUNCTION_LIST"
    })
    return _assetPrefix .. "_" .. _assetId .. "_ASSIGNABLE_FUNCTION"
end
 
-- Register all stone gate set building parts and their properties
StoneGate:dofile(_scriptFolder .. "/basicMain.lua")
StoneGate:dofile(_scriptFolder .. "/basicKeep.lua")
StoneGate:dofile(_scriptFolder .. "/basicLargeGate.lua")
StoneGate:dofile(_scriptFolder .. "/basicSmallSquaredTower.lua")
StoneGate:dofile(_scriptFolder .. "/basicOctogonalTower.lua")
StoneGate:dofile(_scriptFolder .. "/basicSmallGate.lua")
StoneGate:dofile(_scriptFolder .. "/basicAngle45.lua")
StoneGate:dofile(_scriptFolder .. "/basicAngle45Keep.lua")
StoneGate:dofile(_scriptFolder .. "/hoarding.lua")
StoneGate:dofile(_scriptFolder .. "/machicolation.lua")
StoneGate:dofile(_scriptFolder .. "/decoration.lua")
StoneGate:dofile(_scriptFolder .. "/drawBridge.lua")
StoneGate:dofile(_scriptFolder .. "/basicCircularTower.lua")
StoneGate:dofile(_scriptFolder .. "/basicSmallCircularTower.lua")
StoneGate:dofile(_scriptFolder .. "/pointedRoof.lua")
StoneGate:dofile(_scriptFolder .. "/woodenFloor.lua")
StoneGate:dofile(_scriptFolder .. "/woodenFloorWhite.lua", StoneGateSetPrefixWhiteFloor)
StoneGate:dofile(_scriptFolder .. "/baseOverHanging.lua")
StoneGate:dofile(_scriptFolder .. "/assemblage.lua", AssemblagePrefix)
StoneGate:dofile(_scriptFolder .. "/other.lua")
StoneGate:dofile(_scriptFolder .. "/fantasyImport.lua", StoneGateSetPrefix)

StoneGate:registerAsset({
    Id = StoneGateSetPrefix .. "_MONUMENT",
    DataType = "BUILDING",
    AssetCoreBuildingPart = StoneGateSetPrefix .. "_CORE_BUILDING_PART",
    Name = StoneGateSetPrefix .. "_MONUMENT_NAME",
    Description = StoneGateSetPrefix .. "_MONUMENT_DESC",
    BuildingType = "MODS",
    BuildingPartSetList = configureBuildingPartSetList(),
    MaterialSetList = configureMaterialSetList(configureMaterialSet),
    IsEditable = true
})

function registerAuthorityPart(_monument) 
    if _flagAuthority then
	StoneGate:overrideAsset({
		Id = _monument,
		BuildingPartSetList = {
			Action = "APPEND",
			{
				Name = "BUILDING_SET_AUTHORITY3_NAME",
				BuildingPartList = { 
					"BUILDING_PART_AUTHORITY_ASSISTANT",
				}
			},
		}
	})
    end
end
registerAuthorityPart(StoneGateSetPrefix .. "_MONUMENT")

for i,buildingPartSet in ipairs(configureBuildingPartSetList()) do
    StoneGate:overrideAsset({
        Id = "MONUMENT_WOODEN_KEEP",
        BuildingPartSetList = {
                Action = "APPEND",
                buildingPartSet
        }
    })
end
-- not set because it is the choice of the mod Authority to be set on Lord Manor like
-- Anyway the Wooden Keep inclusion is temporary 
-- (waiting for the modding exposure of training)
--registerAuthorityPart("MONUMENT_WOODEN_KEEP")

StoneGate:overrideAsset({
        Id = "MONUMENT_WOODEN_KEEP",
        MaterialSetList = configureMaterialSetList(configureMaterialSet)
})

-- Register all stone gate set building parts and their properties
StoneGate:dofile(_scriptFolder .. "/assignSoldier/compPathAccess.lua")
StoneGate:dofile(_scriptFolder .. "/assignSoldier/compPathAEnd.lua")
StoneGate:dofile(_scriptFolder .. "/assignSoldier/basicWorkplace.lua")
StoneGate:dofile(_scriptFolder .. "/assignSoldier/behavior_tree.lua")

-- Register the stone gate set monument
-- Adds the specific materials od Soldier Assignment to the already existing list of themes
    function configureMaterialSet2(_colorRoof, _colorWall, _colorCrenellation, _colorBasement, _colorFloorGround, _colorFrame, _colorFlag, _defaultMaterial, _custom)
        function configureSimpleRoofAccessMaterial(_core)
            if _defaultMaterial then
                return _assignSoldierPrefix .. "_" .. _core .. "_" .. _colorRoof .. "_ROOF_MATERIAL"
            else
                return CommonWindowPrefix .. "_DECORATION_" .. _colorRoof .. "_ROOF_MATERIAL"
            end
        end
        function configureWallAccessMaterial(_core)
            if _defaultMaterial then
                return _assignSoldierPrefix .. "_" .. _core .. "_" .. _colorWall .. "_WALL_MATERIAL"
            else
                return CommonWindowPrefix .. "_DECORATION_" .. _colorWall .. "_WALL_MATERIAL"
            end
        end

        StoneGate:log("init configureMaterialSet")
        local materialSet = configureMaterialSet(_colorRoof, _colorWall, _colorCrenellation, _colorBasement, _colorFloorGround, _colorFrame, _colorFlag, _defaultMaterial, _custom)
        StoneGate:log("init configureMaterialSet")
        table.insert(materialSet.MaterialList, configureSimpleRoofAccessMaterial("OTOWER"))
        table.insert(materialSet.MaterialList, configureWallAccessMaterial("OTOWER"))
        StoneGate:log("end configureMaterialSet" .. tostring(materialSet))
        return materialSet
    end

    StoneGate:overrideAsset({
        Id = StoneGateSetPrefix .. "_MONUMENT",
        BuildingPartSetList = {
                Action = "APPEND",
		{
			Name = StoneGateSetPrefix .. "_ENTRANCE_PARTSETLIST_NAME",
                	BuildingPartList = {
                            _assignSoldierPrefix .. "_KEEP_TRAP_ACCESS_PART",
                            _assignSoldierPrefix .. "_SMALL_GATE_ACCESS_R_PART",
                            _assignSoldierPrefix .. "_SMALL_GATE_ACCESS_L_PART",
                            _assignSoldierPrefix .. "_OCTOGONAL_TOWER_ACCESS_PART",
                        }
                }
        },
        MaterialSetList = configureMaterialSetList(configureMaterialSet2)
    })

    StoneGate:overrideAsset({
        Id = "MONUMENT_WOODEN_KEEP",
        BuildingPartSetList = {
                Action = "APPEND",
		{
			Name = StoneGateSetPrefix .. "_ENTRANCE_PARTSETLIST_NAME",
                	BuildingPartList = {
                            _assignSoldierPrefix .. "_KEEP_TRAP_ACCESS_PART",
                            _assignSoldierPrefix .. "_SMALL_GATE_ACCESS_R_PART",
                            _assignSoldierPrefix .. "_SMALL_GATE_ACCESS_L_PART",
                            _assignSoldierPrefix .. "_OCTOGONAL_TOWER_ACCESS_PART",
                        }
                }
        },
        MaterialSetList = configureMaterialSetList(configureMaterialSet2)
    })

